/*
Copyright 2024 The Kruise Authors.

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
*/

// Code generated by client-gen. DO NOT EDIT.

package v1alpha1

import (
	"context"
	"time"

	v1alpha1 "github.com/openkruise/kruise-api/apps/v1alpha1"
	scheme "github.com/openkruise/kruise-api/client/clientset/versioned/scheme"
	v1 "k8s.io/apimachinery/pkg/apis/meta/v1"
	types "k8s.io/apimachinery/pkg/types"
	watch "k8s.io/apimachinery/pkg/watch"
	rest "k8s.io/client-go/rest"
)

// WorkloadSpreadsGetter has a method to return a WorkloadSpreadInterface.
// A group's client should implement this interface.
type WorkloadSpreadsGetter interface {
	WorkloadSpreads(namespace string) WorkloadSpreadInterface
}

// WorkloadSpreadInterface has methods to work with WorkloadSpread resources.
type WorkloadSpreadInterface interface {
	Create(ctx context.Context, workloadSpread *v1alpha1.WorkloadSpread, opts v1.CreateOptions) (*v1alpha1.WorkloadSpread, error)
	Update(ctx context.Context, workloadSpread *v1alpha1.WorkloadSpread, opts v1.UpdateOptions) (*v1alpha1.WorkloadSpread, error)
	UpdateStatus(ctx context.Context, workloadSpread *v1alpha1.WorkloadSpread, opts v1.UpdateOptions) (*v1alpha1.WorkloadSpread, error)
	Delete(ctx context.Context, name string, opts v1.DeleteOptions) error
	DeleteCollection(ctx context.Context, opts v1.DeleteOptions, listOpts v1.ListOptions) error
	Get(ctx context.Context, name string, opts v1.GetOptions) (*v1alpha1.WorkloadSpread, error)
	List(ctx context.Context, opts v1.ListOptions) (*v1alpha1.WorkloadSpreadList, error)
	Watch(ctx context.Context, opts v1.ListOptions) (watch.Interface, error)
	Patch(ctx context.Context, name string, pt types.PatchType, data []byte, opts v1.PatchOptions, subresources ...string) (result *v1alpha1.WorkloadSpread, err error)
	WorkloadSpreadExpansion
}

// workloadSpreads implements WorkloadSpreadInterface
type workloadSpreads struct {
	client rest.Interface
	ns     string
}

// newWorkloadSpreads returns a WorkloadSpreads
func newWorkloadSpreads(c *AppsV1alpha1Client, namespace string) *workloadSpreads {
	return &workloadSpreads{
		client: c.RESTClient(),
		ns:     namespace,
	}
}

// Get takes name of the workloadSpread, and returns the corresponding workloadSpread object, and an error if there is any.
func (c *workloadSpreads) Get(ctx context.Context, name string, options v1.GetOptions) (result *v1alpha1.WorkloadSpread, err error) {
	result = &v1alpha1.WorkloadSpread{}
	err = c.client.Get().
		Namespace(c.ns).
		Resource("workloadspreads").
		Name(name).
		VersionedParams(&options, scheme.ParameterCodec).
		Do(ctx).
		Into(result)
	return
}

// List takes label and field selectors, and returns the list of WorkloadSpreads that match those selectors.
func (c *workloadSpreads) List(ctx context.Context, opts v1.ListOptions) (result *v1alpha1.WorkloadSpreadList, err error) {
	var timeout time.Duration
	if opts.TimeoutSeconds != nil {
		timeout = time.Duration(*opts.TimeoutSeconds) * time.Second
	}
	result = &v1alpha1.WorkloadSpreadList{}
	err = c.client.Get().
		Namespace(c.ns).
		Resource("workloadspreads").
		VersionedParams(&opts, scheme.ParameterCodec).
		Timeout(timeout).
		Do(ctx).
		Into(result)
	return
}

// Watch returns a watch.Interface that watches the requested workloadSpreads.
func (c *workloadSpreads) Watch(ctx context.Context, opts v1.ListOptions) (watch.Interface, error) {
	var timeout time.Duration
	if opts.TimeoutSeconds != nil {
		timeout = time.Duration(*opts.TimeoutSeconds) * time.Second
	}
	opts.Watch = true
	return c.client.Get().
		Namespace(c.ns).
		Resource("workloadspreads").
		VersionedParams(&opts, scheme.ParameterCodec).
		Timeout(timeout).
		Watch(ctx)
}

// Create takes the representation of a workloadSpread and creates it.  Returns the server's representation of the workloadSpread, and an error, if there is any.
func (c *workloadSpreads) Create(ctx context.Context, workloadSpread *v1alpha1.WorkloadSpread, opts v1.CreateOptions) (result *v1alpha1.WorkloadSpread, err error) {
	result = &v1alpha1.WorkloadSpread{}
	err = c.client.Post().
		Namespace(c.ns).
		Resource("workloadspreads").
		VersionedParams(&opts, scheme.ParameterCodec).
		Body(workloadSpread).
		Do(ctx).
		Into(result)
	return
}

// Update takes the representation of a workloadSpread and updates it. Returns the server's representation of the workloadSpread, and an error, if there is any.
func (c *workloadSpreads) Update(ctx context.Context, workloadSpread *v1alpha1.WorkloadSpread, opts v1.UpdateOptions) (result *v1alpha1.WorkloadSpread, err error) {
	result = &v1alpha1.WorkloadSpread{}
	err = c.client.Put().
		Namespace(c.ns).
		Resource("workloadspreads").
		Name(workloadSpread.Name).
		VersionedParams(&opts, scheme.ParameterCodec).
		Body(workloadSpread).
		Do(ctx).
		Into(result)
	return
}

// UpdateStatus was generated because the type contains a Status member.
// Add a +genclient:noStatus comment above the type to avoid generating UpdateStatus().
func (c *workloadSpreads) UpdateStatus(ctx context.Context, workloadSpread *v1alpha1.WorkloadSpread, opts v1.UpdateOptions) (result *v1alpha1.WorkloadSpread, err error) {
	result = &v1alpha1.WorkloadSpread{}
	err = c.client.Put().
		Namespace(c.ns).
		Resource("workloadspreads").
		Name(workloadSpread.Name).
		SubResource("status").
		VersionedParams(&opts, scheme.ParameterCodec).
		Body(workloadSpread).
		Do(ctx).
		Into(result)
	return
}

// Delete takes name of the workloadSpread and deletes it. Returns an error if one occurs.
func (c *workloadSpreads) Delete(ctx context.Context, name string, opts v1.DeleteOptions) error {
	return c.client.Delete().
		Namespace(c.ns).
		Resource("workloadspreads").
		Name(name).
		Body(&opts).
		Do(ctx).
		Error()
}

// DeleteCollection deletes a collection of objects.
func (c *workloadSpreads) DeleteCollection(ctx context.Context, opts v1.DeleteOptions, listOpts v1.ListOptions) error {
	var timeout time.Duration
	if listOpts.TimeoutSeconds != nil {
		timeout = time.Duration(*listOpts.TimeoutSeconds) * time.Second
	}
	return c.client.Delete().
		Namespace(c.ns).
		Resource("workloadspreads").
		VersionedParams(&listOpts, scheme.ParameterCodec).
		Timeout(timeout).
		Body(&opts).
		Do(ctx).
		Error()
}

// Patch applies the patch and returns the patched workloadSpread.
func (c *workloadSpreads) Patch(ctx context.Context, name string, pt types.PatchType, data []byte, opts v1.PatchOptions, subresources ...string) (result *v1alpha1.WorkloadSpread, err error) {
	result = &v1alpha1.WorkloadSpread{}
	err = c.client.Patch(pt).
		Namespace(c.ns).
		Resource("workloadspreads").
		Name(name).
		SubResource(subresources...).
		VersionedParams(&opts, scheme.ParameterCodec).
		Body(data).
		Do(ctx).
		Into(result)
	return
}
